/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.internal.common.CommonDialog");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dojox.data.dom");
dojo.require("net.jazz.ajax.ui.internal.Dialog");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.require("com.ibm.rational.report.web.core.app.internal.Util");

var Util    		= com.ibm.rational.report.web.core.app.internal.Util;
var CommonMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");

/**
 * Displays a dialog that supports accessibility.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.internal.common.CommonDialog",
	[net.jazz.ajax.ui.internal.Dialog], {
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/templates/CommonDialog.html"),
	
	_lastFocusItem: null, //used to keep track of the last item that was focused (for accessibility)
	
	postCreate: function () {
		this.inherited("postCreate", arguments);
		this._connect = [];
		this._connect.push(dojo.connect(document.documentElement, "onkeypress", this, "_onKey"));
			
		var ev = typeof(document.ondeactivate) == "object" ? "ondeactivate" : "onblur";
		this._connect.push(dojo.connect(this._bodyContainer, ev, this, "_findLastFocus"));
		
		this._bodyContainer.focus();
		
		Util.removeChildren(this._headerButtons);
		
		var self = this;
		
		if (typeof this.isClosable == "undefined" || this.isClosable) {
			// recreating to add accessibility- the close button isn't displayed when images are disabled.
			this._close = document.createElement("a");
			this._close.href = "#";
			this._close.title = CommonMessages.CLOSE_BUTTON_LABEL;
			this.image = document.createElement("img");
			this.image.src = dojo.moduleUrl("net.jazz.ajax","ui/internal/images/dialog/close.gif");	
			this.image.alt = "X";
			dojo.connect(this._close, "onmouseover", 
				function(e) {
					self.image.src = dojo.moduleUrl("net.jazz.ajax","ui/internal/images/dialog/close-hov.gif");
				});
			dojo.connect(this._close, "onfocus", 
				function(e) {
					self.image.src = dojo.moduleUrl("net.jazz.ajax","ui/internal/images/dialog/close-hov.gif");
				});
			dojo.connect(this._close, "onmouseout", 
				function(e) {
					self.image.src = dojo.moduleUrl("net.jazz.ajax","ui/internal/images/dialog/close.gif");
				});
			dojo.connect(this._close, "onblur", 
				function(e){
					self.image.src = dojo.moduleUrl("net.jazz.ajax","ui/internal/images/dialog/close.gif");
				});
			this._close.appendChild(this.image);
			this._headerButtons.appendChild(this._close);
			this.connect(this._close, 'onclick', this.close);	
		}
	},
			
	disableCloseButton: function() {
		this._close.disabled = true;
	},
	
	close: function() {
		this.inherited("close", arguments);
		dojo.forEach(this._connect, dojo.disconnect);
		this.connects = [];
	},
	
	enableCloseButton: function() {
		this._close.disabled = false;
	},
	
	_findLastFocus: function(evt) {
		this._lastFocused = evt.target;
	},
	
	_cycleFocus: function(/*Event*/ evt) {
		// summary: when tabEnd receives focus, advance focus around to titleBar
		// on first focus to tabEnd, store the last focused item in dialog
		if (!this._lastFocusItem) {
			this._lastFocusItem = this._lastFocused;
		}
		this._header.focus();
	},
	
	_onKey: function(evt) {	
		if (evt.keyCode) {
			var node = evt.target;
			// see if we are shift-tabbing from titleBar
			if(node == this._header && evt.shiftKey && evt.keyCode == dojo.keys.TAB){
				if (this._lastFocusItem) {
					this._lastFocusItem.focus(); // send focus to last item in dialog if known
				}
				dojo.stopEvent(evt);
			} else {
				// see if the key is for the dialog
				while(node) {
					if (node == this.domNode) {
						if (evt.keyCode == dojo.keys.ESCAPE && (typeof this.isClosable == "undefined" || this.isClosable)) {
							this.close(); 
						} else {
							return; // just let it go
						}
					}
					node = node.parentNode;
				}
				// this key is for the disabled document window
				if (evt.keyCode != dojo.keys.TAB) { // allow tabbing into the dialog for a11y
					dojo.stopEvent(evt);
				} else if (!dojo.isOpera) { // opera won't tab to a div
					try {
						this._header.focus();
					} catch(e) {
					}
				}
			}
		}
	}
	
});

})();